@@ -4,14 +4,14 @@ use strict;
 use warnings;
 use Schedule::Activity::Attribute;
 
-our $VERSION='0.1.3';
+our $VERSION='0.1.4';
 
 sub new {
 	my ($ref,%opt)=@_;
 	my $class=ref($ref)||$ref;
 	my %self=(
-		attr    =>{},
-		# internal=>{}, # not yet needed
+		attr =>{},
+		stack=>[],
 	);
 	return bless(\%self,$class);
 }
@@ -54,6 +54,23 @@ sub report {
 	return %res;
 }
 
+sub push {
+	my ($self)=@_;
+	my %state;
+	while(my ($k,$v)=each %{$$self{attr}}) { %{$state{$k}}=$v->dump() }
+	push @{$$self{stack}},\%state;
+	return $self;
+}
+
+sub pop {
+	my ($self)=@_;
+	if(!@{$$self{stack}}) { return $self }
+	my %state=%{pop @{$$self{stack}}};
+	%{$$self{attr}}=();
+	while(my ($k,$v)=each %state) { $$self{attr}{$k}=Schedule::Activity::Attribute->restore(%$v) }
+	return $self;
+}
+
 1;
 
 __END__
